<?php

namespace Drupal\Tests\token_or\Kernel;

use Drupal\KernelTests\KernelTestBase;

/**
 * Tests the Token Or module.
 *
 * @group token_or
 * @requires module token
 */
class TokenOrTest extends KernelTestBase {

  /**
   * The example site name for these tests.
   *
   * @var string
   */
  protected static $siteName = 'foobar';

  /**
   * The string replacement value for these tests.
   *
   * @var string
   */
  protected static $stringReplacement = 'baz';

  /**
   * Token service.
   *
   * @var \Drupal\Core\Utility\Token
   */
  protected $tokenService;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'system',
    'token',
    'token_or',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $config = \Drupal::service('config.factory')->getEditable('system.site');
    $config->set('name', self::$siteName);
    $config->save();
    $this->tokenService = \Drupal::token();
  }

  /**
   * Test callback.
   */
  public function testTokenReplacement() {
    $value = $this->tokenService->replace('[site:mail|site:name]');
    $this->assertEquals(self::$siteName, $value);
  }

  /**
   * Test callback.
   */
  public function testStringReplacement() {
    $value = $this->tokenService->replace('[site:mail|"' . self::$stringReplacement . '"]');
    $this->assertEquals(self::$stringReplacement, $value);
  }

}
